#
# spec file for package ghc-tasty-rerun
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name tasty-rerun
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        1.1.19
Release:        4.5
Summary:        Rerun only tests which failed in a previous test run
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/3.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-optparse-applicative-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-split-prof
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-tagged-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}

%description
This ingredient for the <https://hackage.haskell.org/package/tasty tasty>
testing framework allows filtering a test tree depending on the outcome of the
previous run. This may be useful in many scenarios, especially when a test
suite grows large.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc Changelog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Fri Mar 15 2024 Peter Simons <psimons@suse.com>
- Update tasty-rerun to version 1.1.19 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Oct 15 2023 Peter Simons <psimons@suse.com>
- Update tasty-rerun to version 1.1.19 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Sep 27 2023 Peter Simons <psimons@suse.com>
- Update tasty-rerun to version 1.1.19 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Sep 10 2023 Peter Simons <psimons@suse.com>
- Update tasty-rerun to version 1.1.19.
  [#] 1.1.19
  * Support tasty 1.5.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Jan 29 2023 Peter Simons <psimons@suse.com>
- Update tasty-rerun to version 1.1.18 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed May  4 2022 Peter Simons <psimons@suse.com>
- Update tasty-rerun to version 1.1.18 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Sep  7 2021 psimons@suse.com
- Update tasty-rerun to version 1.1.18 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jan  4 2021 psimons@suse.com
- Update tasty-rerun to version 1.1.18 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Thu Oct 29 2020 psimons@suse.com
- Update tasty-rerun to version 1.1.18.
  [#] 1.1.18
  * Support tasty 1.4.
* Mon Aug 31 2020 psimons@suse.com
- Update tasty-rerun to version 1.1.17 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add tasty-rerun at version 1.1.17.
